pub struct TokenRequestBody {
pub client_parameters: ClientParameters,
pub room_parameters: Option<RoomParameters>,
}Expand description
The request body for GET /rooms/{room_id}/token
Fields
client_parameters: ClientParametersInformation regarding the requesting client
room_parameters: Option<RoomParameters>The room that the token is requested for.
Once this was provided to the roomserver, further request do not need to include the room parameters