pub struct ClientParameters {
pub device_secret: DeviceSecret,
pub kind: ClientKind,
pub role: Role,
}Expand description
Client context required for a signaling connection
Fields
device_secret: DeviceSecretIdentifier to maintain participant state across reconnections, is generated by the client
kind: ClientKindInformation about a registered user
role: RoleThe role that the client assumes in the meeting.