ModuleSettings

Struct ModuleSettings 

pub struct ModuleSettings(/* private fields */);
A struct containing settings for multiple signaling modules, each associated with the module’s namespace.

Implementations

Source

impl ModuleSettings

pub fn new() -> Self

Create a new empty ModuleSettings.

pub fn get<T: SignalingModuleSettings>(&self) -> Result<Option<T>, Error>

Get the settings for a specific module

pub fn insert<T: SignalingModuleSettings>( &mut self, data: &T, ) -> Result<(), Error>

Set the settings for a specific module

If an entry with the namespace already exists, it will be overwritten.

pub fn insert_empty(&mut self, namespace: ModuleId)

Insert an empty object for the specified module namespace

This is useful for adding modules that don’t require any settings.

pub fn remove(&mut self, namespace: &ModuleId) -> Option<Value>

Remove the settings for a specified module.

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&ModuleId, &mut Value) -> bool,

Retains only the entries specified by the predicate

pub fn ids(&self) -> impl Iterator<Item = &ModuleId>

Returns an iterator over the module IDs in the settings

pub fn contains(&self, namespace: ModuleId) -> bool

Checks if specified module id is present in the settings