pub struct ModuleSettings(/* private fields */);Expand description
A struct containing settings for multiple signaling modules, each associated with the module’s namespace.
Implementations
Sourceimpl ModuleSettings
impl ModuleSettings
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new empty ModuleSettings.
Sourcepub fn get<T: SignalingModuleSettings>(&self) -> Result<Option<T>, Error>
pub fn get<T: SignalingModuleSettings>(&self) -> Result<Option<T>, Error>
Get the settings for a specific module
Sourcepub fn insert<T: SignalingModuleSettings>(
&mut self,
data: &T,
) -> Result<(), Error>
pub fn insert<T: SignalingModuleSettings>( &mut self, data: &T, ) -> Result<(), Error>
Set the settings for a specific module
If an entry with the namespace already exists, it will be overwritten.
Sourcepub fn insert_empty(&mut self, namespace: ModuleId)
pub fn insert_empty(&mut self, namespace: ModuleId)
Insert an empty object for the specified module namespace
This is useful for adding modules that don’t require any settings.
Sourcepub fn remove(&mut self, namespace: &ModuleId) -> Option<Value>
pub fn remove(&mut self, namespace: &ModuleId) -> Option<Value>
Remove the settings for a specified module.